<?php
/* 
Description: Core Library Database Access functions

Copyright 2014 Malcolm Shergold

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

require_once "stageshowlib_utils.php";

if (!class_exists('StageShowLibGenericDBaseClass'))
{
	if (!defined('STAGESHOWLIB_DATETIME_ADMIN_FORMAT'))
		define('STAGESHOWLIB_DATETIME_ADMIN_FORMAT', 'Y-m-d H:i');

	class StageShowLibGenericDBaseClass // Define class
	{
		var $hideSQLErrors = false;
		
		// This class does nothing when running under WP
		// Overload this class with DB access functions for non-WP access
		function __construct() //constructor		
		{
			$this->GetLoginID();
			$this->SetMySQLGlobals();
		}	
		
		static function IsInWP()
		{
			// Use a WP define to find out if WP is loaded
			return defined('WPINC');
		}
		
		function GetLoginID()
		{
			if (!defined('CORONDECK_RUNASDEMO'))	// Get Current User ID in Demo mode
				return '';
				
			if (isset($this->loginID))
				return $this->loginID;
				
			if (isset($_REQUEST['loginID']))
			{
				$this->loginID = $_REQUEST['loginID'];
				return $this->loginID;
			}
								
			if (!function_exists('get_currentuserinfo'))
			{
				require_once( ABSPATH . WPINC . '/pluggable.php' );
			}
			global $current_user;
				
      		get_currentuserinfo();

			if (isset($current_user->user_login))
				$this->loginID = $current_user->user_login;	
			else
				$this->loginID = '';
			
			return $this->loginID;
		}
		
		function SetMySQLGlobals()
		{			
			$this->hideSQLErrors = true;
			$rtnVal = $this->query("SET SQL_BIG_SELECTS=1");
			$this->hideSQLErrors = false;
			if (!$rtnVal)
			{
				// Use the old version of the query if it fails
				$rtnVal = $this->query("SET OPTION SQL_BIG_SELECTS=1");
			}
			
			return $rtnVal;
		}
		
		function ShowDBErrors()
		{
			if ($this->hideSQLErrors)
				return;
				
			global $wpdb;
			if ($wpdb->last_error == '')
				return;
				
			echo '<div id="message" class="error"><p>'.$wpdb->last_error.'</p></div>';
		}

		function ShowSQL($sql, $values = null)
		{			
			if (!$this->isDbgOptionSet('Dev_ShowSQL'))
			{
				return;				
			}
			
			if ($this->isDbgOptionSet('Dev_ShowCallStack'))
			{
				StageShowLibUtilsClass::ShowCallStack();
			}
			
			$sql = htmlspecialchars($sql);
			$sql = str_replace("\n", "<br>\n", $sql);
			echo "<br>$sql<br>\n";
			if (isset($values))
			{
				print_r($values);
				echo "<br>\n";
			}
		}
		
		function queryWithPrepare($sql, $values)
		{
			global $wpdb;
			
			$sql = $wpdb->prepare($sql, $values);
			
			return $this->query($sql);
		}
		
		function query($sql)
		{
			global $wpdb;
			
			if (defined('CORONDECK_RUNASDEMO'))
			{
				$sql = $this->SQLForDemo($sql);
			}	
			
			$this->ShowSQL($sql);

			if ($this->hideSQLErrors)
			{
				$suppress_errors = $wpdb->suppress_errors;
				$wpdb->suppress_errors = true;
			}
			$this->queryResult = $wpdb->query($sql);
			if ($this->isDbgOptionSet('Dev_ShowDBOutput'))
			{
				echo "Query Result: $this->queryResult<br>\n";
			}
			$rtnStatus = ($this->queryResult !== false);	
			if ($this->hideSQLErrors)
			{
				$wpdb->suppress_errors = $suppress_errors;				
			}
			else
			{
				$this->ShowDBErrors();
			}		
			
			return $rtnStatus;		
		}

		function GetInsertId()
		{
			global $wpdb;
			
			return $wpdb->insert_id;
		}

		function getresultsWithPrepare($sql, $values)
		{
			global $wpdb;
			
			$sql = $wpdb->prepare($sql, $values);
			
			return $this->get_results($sql);
		}
		
		function get_results($sql, $debugOutAllowed = true, $sqlFilters = array())
		{
			global $wpdb;
			
			if (defined('CORONDECK_RUNASDEMO') && !isset($sqlFilters['noLoginID']))
			{
				$sql = $this->SQLForDemo($sql);
			}	
			
			$this->ShowSQL($sql);
			$results = $wpdb->get_results($sql);
			if ($debugOutAllowed) $this->show_results($results);
			
			$this->ShowDBErrors();
			
			return $results;
		}
		
		function show_results($results)
		{
			if (!$this->isDbgOptionSet('Dev_ShowDBOutput'))
			{				
				if ($this->isDbgOptionSet('Dev_ShowSQL'))
				{
					$entriesCount = count($results);
					echo "Database Result Entries: $entriesCount<br>\n";
					return;				
				}
				return;
			}
				
			if (function_exists('wp_get_current_user'))
			{
				if (!$this->isSysAdmin())
					return;				
			}
				
			echo "<br>Database Results:<br>\n";
			for ($i = 0; $i < count($results); $i++)
				echo "Array[$i] = " . print_r($results[$i], true) . "<br>\n";
		}
		
		function GetSQLBlockEnd($sql, $startPosn, $startChar = '(', $endChar = ')')
		{
			$posn = $startPosn;
			$len = strlen($sql);
			$matchCount = 0;
			
			while ($posn < $len)
			{
				$nxtChar = $sql[$posn];
				if ($nxtChar == $startChar)
				{
					$matchCount++;
				}
				else if ($nxtChar == $endChar)
				{
					$matchCount--;
					if ($matchCount == 0)
					{
						return $posn;
					}
				}
				$posn++;
			}
			
			return -1;
		}
		
		function SQLForDemo($sql)
		{
			if (!defined('CORONDECK_RUNASDEMO'))
				return $sql;
			
			if (strpos($sql, 'loginID') !== false)
				return $sql;
				
			$sqlDemo = $sql;
				
			// First get the command type (first word) ...
			if (preg_match('/(\w*)/', $sql, $matches) == 0) 
			{
				return $sql;
			}
			
			$sqlCmd = $matches[0];
			
			switch ($sqlCmd)
			{
				case 'SELECT':
				case 'DELETE':
					// SELECT query .... add the loginID to the query
					$sqlDemo = str_replace('( SELECT', '(SELECT', $sqlDemo);
										
					$srchpos = 0;
					$bpos = strlen($sqlDemo);	
					$catchCount = 10;				
					while ($bpos !== false)
					{
						if ($catchCount-- <=0 ) break;
						// Find the last (SELECT entry ....
						if (($bpos = strrpos($sqlDemo, '(SELECT', $bpos-strlen($sqlDemo))) !== false)
						{
							$srchpos = $this->GetSQLBlockEnd($sqlDemo, $bpos);
							$sqlBlock = substr($sqlDemo, $bpos, $srchpos-$bpos);
							$regexStart = '\(SELECT';
							$bpos = $bpos-1;
						}
						else
						{
							$srchpos = $this->GetSQLBlockEnd($sqlDemo, 0);
							$sqlBlock = $sqlDemo;
							$regexStart = $sqlCmd;
							$bpos = false;
						}
						
						$loginIDField = 'loginID';
						$loginSelector = '';
						
						$regex = '/'.$regexStart.'(.*?)FROM\s*([a-zA-Z_\(]*)\s*([a-z_]*)/';
						preg_match($regex, $sqlBlock, $matches, 0, 0);
						if ( (count($matches) >= 2) && (strlen($matches[2]) > 0)  && ($matches[2][0] != '(') )
						{
							if ((count($matches) >= 3) && (strlen(trim($matches[3])) > 0))
								$loginIDField = $matches[3].'.loginID';
							else	
								$loginIDField = $matches[2].'.loginID';
								
							$selectFields = $matches[1];
							if ( (strpos('*', str_replace('(*)', '', $selectFields)) === false)
							  && ($sqlCmd == 'SELECT') )
							{
								$loginSelector = " , $loginIDField ";
							}
						}
						
						$where = ' where '.$loginIDField.' = "'.$this->loginID.'" ';					
					
						$sqlSrchCmd = '';
						if (strpos($sqlBlock, 'WHERE') !== false)
						{
							$sqlSrchCmd = 'WHERE';
							$sqlReplCmd = 'AND';
						}
						else if (strpos($sqlBlock, 'GROUP BY') !== false)
						{
							$sqlSrchCmd = 'GROUP BY';
							$sqlReplCmd = 'group by';
						}
						else if (strpos($sqlBlock, 'ORDER BY') !== false)
						{
							$sqlSrchCmd = 'ORDER BY';
							$sqlReplCmd = 'order by';
						}

						if ($sqlSrchCmd != '')
						{
							$sqlEditedBlock = str_replace($sqlSrchCmd, "$where $sqlReplCmd", $sqlBlock);
							$sqlEditedBlock = str_replace('SELECT ', 'select ', $sqlEditedBlock);
							$sqlEditedBlock = str_replace(' FROM ', " $loginSelector from ", $sqlEditedBlock);
						}
						else
						{
							$sqlEditedBlock = $sqlBlock.$where;
						}
						
						$sqlEditedBlock = str_replace(' WHERE ', ' where ', $sqlEditedBlock);						
						$sqlEditedBlock = str_replace(' ORDER BY ', ' order by ', $sqlEditedBlock);						
						$sqlEditedBlock = str_replace(' GROUP BY ', ' group by ', $sqlEditedBlock);						
						$sqlDemo = str_replace($sqlBlock, $sqlEditedBlock, $sqlDemo);
					}
					$sqlDemo = str_replace(' where ', ' WHERE ', $sqlDemo);						
					$sqlDemo = str_replace(' order by ', ' ORDER BY ', $sqlDemo);						
					$sqlDemo = str_replace(' group by ', ' GROUP BY ', $sqlDemo);						
					$sqlDemo = str_replace('select ', 'SELECT ', $sqlDemo);
					$sqlDemo = str_replace(' from ',  ' FROM ', $sqlDemo);
					break;
				
				case 'UPDATE':
					// SELECT query .... add the loginID to the query
					$where = ' WHERE loginID = "'.$this->loginID.'" ';
					
					if (strpos($sqlDemo, 'WHERE') !== false)
					{
						$sqlDemo = str_replace("WHERE", "$where AND", $sqlDemo);
					}
					break;
				
				case 'INSERT':
					$sqlDemo = preg_replace('/\(/', '(loginID, ', $sqlDemo, 1);
					$sqlDemo = str_replace('VALUES(', 'VALUES("'.$this->loginID.'", ', $sqlDemo);
					break;
				
				case 'ALTER':
				case 'LOCK':
				case 'UNLOCK':
				case 'SET':
					return $sql;
				
				case 'SHOW':
					return $sql;
			}
								
			if ($sqlDemo === $sql)
			{
				echo "<br><strong>ERROR: SQL not processed for DEMO mode: </strong><br>SQL: $sql<br>\n";
				die;				
			}
			
			return $sqlDemo;
		}
		
		function isDbgOptionSet($optionID)
		{
			return false;
		}
       
		static function FormatDateForAdminDisplay($dateInDB)
		{
			// Convert time string to UNIX timestamp
			$timestamp = strtotime( $dateInDB );
			
			// Get Time & Date formatted for display to user
			return date(STAGESHOWLIB_DATETIME_ADMIN_FORMAT, $timestamp);
		}
		
	}
}

?>